@@ -1,7 +1,7 @@
 package Pod::Weaver::Plugin::Rinci;
 
-our $DATE = '2015-02-18'; # DATE
-our $VERSION = '0.31'; # VERSION
+our $DATE = '2015-02-21'; # DATE
+our $VERSION = '0.32'; # VERSION
 
 use 5.010001;
 use Moose;
@@ -266,10 +266,14 @@ sub _process_script {
             my $sc_spec = $cli->{subcommands}{$sc_name};
             my $meta = $metas{$sc_name};
             push @content, "=head2 B<$sc_name>\n\n";
-            push @content, "$meta->{summary}.\n\n" if $meta->{summary};
-            if ($meta->{description}) {
+
+            my $summary = $sc_spec->{summary} // $meta->{summary};
+            push @content, "$summary.\n\n" if $summary;
+
+            my $description = $sc_spec->{description} // $meta->{description};
+            if ($description) {
                 push @content,
-                    Markdown::To::POD::markdown_to_pod($meta->{description});
+                    Markdown::To::POD::markdown_to_pod($description);
                 push @content, "\n\n";
             }
         }
@@ -459,7 +463,7 @@ Pod::Weaver::Plugin::Rinci - Insert stuffs to POD from Rinci metadata
 
 =head1 VERSION
 
-This document describes version 0.31 of Pod::Weaver::Plugin::Rinci (from Perl distribution Pod-Weaver-Plugin-Rinci), released on 2015-02-18.
+This document describes version 0.32 of Pod::Weaver::Plugin::Rinci (from Perl distribution Pod-Weaver-Plugin-Rinci), released on 2015-02-21.
 
 =head1 SYNOPSIS
 
@@ -556,7 +560,7 @@ Please visit the project's homepage at L<https://metacpan.org/release/Pod-Weaver
 
 =head1 SOURCE
 
-Source repository is at L<https://github.com/perlancar/perl-Pod-Weaver-Plugin-Perinci>.
+Source repository is at L<https://github.com/perlancar/perl-Pod-Weaver-Plugin-Rinci>.
 
 =head1 BUGS
 
